
From: Arjan van de Ven <arjanv@redhat.com>

ide-iops.c exports a few functions that either have no users or have no
users AND shouldn't be used by drivers; the patch below unexports them.

-EXPORT_SYMBOL(SELECT_INTERRUPT);
-EXPORT_SYMBOL(SELECT_MASK);
-EXPORT_SYMBOL(QUIRK_LIST);
-EXPORT_SYMBOL(ata_vlb_sync);

only used in the core ide code

-EXPORT_SYMBOL(ata_input_data);
-EXPORT_SYMBOL(ata_output_data);

drivers should (and do) use the hwif-> function pointer variant of these,
these functions are internal and used for setting the default hwif->
function pointers only. No need to export, in fact exporting is only asking
for accidents

Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/drivers/ide/ide-iops.c |   12 ------------
 1 files changed, 12 deletions(-)

diff -puN drivers/ide/ide-iops.c~remove-unused-internal-exports-from-ide-core drivers/ide/ide-iops.c
--- 25/drivers/ide/ide-iops.c~remove-unused-internal-exports-from-ide-core	2004-10-24 02:06:31.845917504 -0700
+++ 25-akpm/drivers/ide/ide-iops.c	2004-10-24 02:06:31.849916896 -0700
@@ -221,24 +221,18 @@ void SELECT_INTERRUPT (ide_drive_t *driv
 		HWIF(drive)->OUTB(drive->ctl|2, IDE_CONTROL_REG);
 }
 
-EXPORT_SYMBOL(SELECT_INTERRUPT);
-
 void SELECT_MASK (ide_drive_t *drive, int mask)
 {
 	if (HWIF(drive)->maskproc)
 		HWIF(drive)->maskproc(drive, mask);
 }
 
-EXPORT_SYMBOL(SELECT_MASK);
-
 void QUIRK_LIST (ide_drive_t *drive)
 {
 	if (HWIF(drive)->quirkproc)
 		drive->quirk_list = HWIF(drive)->quirkproc(drive);
 }
 
-EXPORT_SYMBOL(QUIRK_LIST);
-
 /*
  * Some localbus EIDE interfaces require a special access sequence
  * when using 32-bit I/O instructions to transfer data.  We call this
@@ -253,8 +247,6 @@ void ata_vlb_sync (ide_drive_t *drive, u
 	(void) HWIF(drive)->INB(port);
 }
 
-EXPORT_SYMBOL(ata_vlb_sync);
-
 /*
  * This is used for most PIO data transfers *from* the IDE interface
  */
@@ -277,8 +269,6 @@ void ata_input_data (ide_drive_t *drive,
 	}
 }
 
-EXPORT_SYMBOL(ata_input_data);
-
 /*
  * This is used for most PIO data transfers *to* the IDE interface
  */
@@ -301,8 +291,6 @@ void ata_output_data (ide_drive_t *drive
 	}
 }
 
-EXPORT_SYMBOL(ata_output_data);
-
 /*
  * The following routines are mainly used by the ATAPI drivers.
  *
_
